==> pipewire-docs-1%3A0.3.30-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/audio_8h.js <==
var audio_8h =
[
    [ "spa_bluetooth_audio_codec", "group__spa__param.html#ga741ca54fc7f93308779660120bbed31e", [
      [ "SPA_BLUETOOTH_AUDIO_CODEC_START", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31eae880c12653ce2c55c21103c18c06b9e1", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_SBC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea85ef2cecf77fc993d1db899647092573", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_SBC_XQ", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea9d68665eec418ab99ce7e4a6a6486004", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_MPEG", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea29bdfeba283d1e4c809a04d7e2da14f7", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_AAC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea6bf40e69810e357cb666fb2d5f7506a2", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_APTX", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea3feca05cc1d25a940d6dcb5096fd84a2", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_APTX_HD", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31eab59ac179bb624dfa337b2cd34e1ce84e", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_LDAC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31eab908b97e5512e443f4eff7a8d558640b", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_CVSD", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea31cbd5df0a8593a28d28a32af188ea94", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_MSBC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea323c62f4fba490c78c6e34dce099a47f", null ]
    ] ]
];

==> pipewire-docs-1%3A0.3.34-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/audio_8h.js <==
var audio_8h =
[
    [ "spa_bluetooth_audio_codec", "group__spa__param.html#ga741ca54fc7f93308779660120bbed31e", [
      [ "SPA_BLUETOOTH_AUDIO_CODEC_START", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31eae880c12653ce2c55c21103c18c06b9e1", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_SBC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea85ef2cecf77fc993d1db899647092573", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_SBC_XQ", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea9d68665eec418ab99ce7e4a6a6486004", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_MPEG", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea29bdfeba283d1e4c809a04d7e2da14f7", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_AAC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea6bf40e69810e357cb666fb2d5f7506a2", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_APTX", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea3feca05cc1d25a940d6dcb5096fd84a2", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_APTX_HD", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31eab59ac179bb624dfa337b2cd34e1ce84e", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_LDAC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31eab908b97e5512e443f4eff7a8d558640b", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_APTX_LL", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea362a1e43b27a9077f6c0217041a08618", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_APTX_LL_DUPLEX", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea4f11de52e0460d4da1940dc16700709f", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_FASTSTREAM", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ead6da3008c6b2b2a532d1d90d79cba58e", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_FASTSTREAM_DUPLEX", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea371f4523bc8dba0cba42242ff63e8faa", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_CVSD", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea31cbd5df0a8593a28d28a32af188ea94", null ],
      [ "SPA_BLUETOOTH_AUDIO_CODEC_MSBC", "group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea323c62f4fba490c78c6e34dce099a47f", null ]
    ] ]
];
